# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .block_state_updated_data_update_type import BlockStateUpdatedDataUpdateType
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BlockStateUpdatedData(UncheckedBaseModel):
    workflow_id: str
    workflow_run_id: str
    block_id: typing.Optional[str] = None
    block_type: str = pydantic.Field()
    """
    The block archetype ID
    """

    update_data: typing.Dict[str, typing.Optional[typing.Any]]
    update_type: typing.Optional[BlockStateUpdatedDataUpdateType] = pydantic.Field(default=None)
    """
    If `complete` represents a full replacement of state, versus `partial` that indicates data must be _merged_.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowRunFailedEnvironment = typing.Union[typing.Literal["development", "preview", "production", "test"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

from .types import WorkflowsRunRequestInputsValue, WorkflowsRunStreamRequestInputsValue

__all__ = ["WorkflowsRunRequestInputsValue", "WorkflowsRunStreamRequestInputsValue"]



# This file was auto-generated by Fern from our API Definition.

from .documents_create_request import DocumentsCreateRequest
from .documents_create_request_item_value import DocumentsCreateRequestItemValue
from .documents_create_request_zero_value import DocumentsCreateRequestZeroValue
from .documents_update_request_value import DocumentsUpdateRequestValue

__all__ = [
    "DocumentsCreateRequest",
    "DocumentsCreateRequestItemValue",
    "DocumentsCreateRequestZeroValue",
    "DocumentsUpdateRequestValue",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.eval_service_handlers_get_documents_response import EvalServiceHandlersGetDocumentsResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from .types.documents_create_request import DocumentsCreateRequest
from ..types.eval_service_handlers_create_document_response import EvalServiceHandlersCreateDocumentResponse
from ..types.eval_service_handlers_get_document_response import EvalServiceHandlersGetDocumentResponse
from .types.documents_update_request_value import DocumentsUpdateRequestValue
from ..types.eval_service_handlers_update_document_response import EvalServiceHandlersUpdateDocumentResponse
from ..types.eval_service_handlers_delete_document_response import EvalServiceHandlersDeleteDocumentResponse
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class DocumentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EvalServiceHandlersGetDocumentsResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersGetDocumentsResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.documents.list(
            collection_id="collection_id",
            table_id="table_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersGetDocumentsResponse,
                    construct_type(
                        type_=EvalServiceHandlersGetDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: DocumentsCreateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersCreateDocumentResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request : DocumentsCreateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersCreateDocumentResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.documents.create(
            collection_id="collection_id",
            table_id="table_id",
            request={"key": True},
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersCreateDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersCreateDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersGetDocumentResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersGetDocumentResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.documents.get(
            collection_id="collection_id",
            table_id="table_id",
            document_id="document_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersGetDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersGetDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self,
        collection_id: str,
        document_id: str,
        table_id: str,
        *,
        request: typing.Dict[str, DocumentsUpdateRequestValue],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersUpdateDocumentResponse:
        """
        Parameters
        ----------
        collection_id : str

        document_id : str

        table_id : str

        request : typing.Dict[str, DocumentsUpdateRequestValue]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersUpdateDocumentResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.documents.update(
            collection_id="collection_id",
            document_id="document_id",
            table_id="table_id",
            request={"key": True},
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="PUT",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersUpdateDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersUpdateDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersDeleteDocumentResponse:
        """
        Delete a document given a document_id.

        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersDeleteDocumentResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.documents.delete(
            collection_id="collection_id",
            table_id="table_id",
            document_id="document_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersDeleteDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersDeleteDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncDocumentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EvalServiceHandlersGetDocumentsResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersGetDocumentsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.documents.list(
                collection_id="collection_id",
                table_id="table_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersGetDocumentsResponse,
                    construct_type(
                        type_=EvalServiceHandlersGetDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: DocumentsCreateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersCreateDocumentResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request : DocumentsCreateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersCreateDocumentResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.documents.create(
                collection_id="collection_id",
                table_id="table_id",
                request={"key": True},
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersCreateDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersCreateDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersGetDocumentResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersGetDocumentResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.documents.get(
                collection_id="collection_id",
                table_id="table_id",
                document_id="document_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersGetDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersGetDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self,
        collection_id: str,
        document_id: str,
        table_id: str,
        *,
        request: typing.Dict[str, DocumentsUpdateRequestValue],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersUpdateDocumentResponse:
        """
        Parameters
        ----------
        collection_id : str

        document_id : str

        table_id : str

        request : typing.Dict[str, DocumentsUpdateRequestValue]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersUpdateDocumentResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.documents.update(
                collection_id="collection_id",
                document_id="document_id",
                table_id="table_id",
                request={"key": True},
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="PUT",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersUpdateDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersUpdateDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvalServiceHandlersDeleteDocumentResponse:
        """
        Delete a document given a document_id.

        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvalServiceHandlersDeleteDocumentResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.documents.delete(
                collection_id="collection_id",
                table_id="table_id",
                document_id="document_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EvalServiceHandlersDeleteDocumentResponse,
                    construct_type(
                        type_=EvalServiceHandlersDeleteDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from .documents_create_request_zero_value import DocumentsCreateRequestZeroValue
from .documents_create_request_item_value import DocumentsCreateRequestItemValue

DocumentsCreateRequest = typing.Union[
    typing.Dict[str, DocumentsCreateRequestZeroValue], typing.List[typing.Dict[str, DocumentsCreateRequestItemValue]]
]



# This file was auto-generated by Fern from our API Definition.

from .actor import Actor
from .actor_type import ActorType
from .api_key_identity import ApiKeyIdentity
from .apps_service_handlers_create_copilot_response import AppsServiceHandlersCreateCopilotResponse
from .apps_service_handlers_create_workflow_response import AppsServiceHandlersCreateWorkflowResponse
from .apps_service_handlers_delete_copilot_response import AppsServiceHandlersDeleteCopilotResponse
from .apps_service_handlers_delete_workflow_response import AppsServiceHandlersDeleteWorkflowResponse
from .apps_service_handlers_delete_workflow_revision_response import AppsServiceHandlersDeleteWorkflowRevisionResponse
from .apps_service_handlers_get_copilot_response import AppsServiceHandlersGetCopilotResponse
from .apps_service_handlers_get_workflow_environments_response import AppsServiceHandlersGetWorkflowEnvironmentsResponse
from .apps_service_handlers_get_workflow_response import AppsServiceHandlersGetWorkflowResponse
from .apps_service_handlers_list_copilots_response import AppsServiceHandlersListCopilotsResponse
from .apps_service_handlers_list_workflow_revisions_response import AppsServiceHandlersListWorkflowRevisionsResponse
from .apps_service_handlers_list_workflows_response import AppsServiceHandlersListWorkflowsResponse
from .apps_service_handlers_promote_workflow_revision_response import AppsServiceHandlersPromoteWorkflowRevisionResponse
from .apps_service_handlers_update_copilot_response import AppsServiceHandlersUpdateCopilotResponse
from .apps_service_handlers_update_workflow_environment_response import (
    AppsServiceHandlersUpdateWorkflowEnvironmentResponse,
)
from .apps_service_handlers_update_workflow_response import AppsServiceHandlersUpdateWorkflowResponse
from .block_config_item_boolean import BlockConfigItemBoolean
from .block_config_item_json import BlockConfigItemJson
from .block_config_item_llm import BlockConfigItemLlm
from .block_config_item_number import BlockConfigItemNumber
from .block_config_item_number_default_value import BlockConfigItemNumberDefaultValue
from .block_config_item_number_maximum_value import BlockConfigItemNumberMaximumValue
from .block_config_item_number_minimum_value import BlockConfigItemNumberMinimumValue
from .block_config_item_number_value import BlockConfigItemNumberValue
from .block_config_item_select import BlockConfigItemSelect
from .block_config_item_text_long import BlockConfigItemTextLong
from .block_config_item_text_long_value import BlockConfigItemTextLongValue
from .block_config_item_text_short import BlockConfigItemTextShort
from .block_input import BlockInput
from .block_input_block_config_item import BlockInputBlockConfigItem
from .block_output import BlockOutput
from .block_output_block_config_item import BlockOutputBlockConfigItem
from .block_run_completed import BlockRunCompleted
from .block_run_completed_data import BlockRunCompletedData
from .block_run_completed_environment import BlockRunCompletedEnvironment
from .block_run_failed import BlockRunFailed
from .block_run_failed_data import BlockRunFailedData
from .block_run_failed_environment import BlockRunFailedEnvironment
from .block_run_started import BlockRunStarted
from .block_run_started_data import BlockRunStartedData
from .block_run_started_environment import BlockRunStartedEnvironment
from .block_run_usage import BlockRunUsage
from .block_state_updated import BlockStateUpdated
from .block_state_updated_data import BlockStateUpdatedData
from .block_state_updated_data_update_type import BlockStateUpdatedDataUpdateType
from .block_state_updated_environment import BlockStateUpdatedEnvironment
from .check_box_column import CheckBoxColumn
from .collection import Collection
from .collection_config import CollectionConfig
from .copilot import Copilot
from .copilot_config import CopilotConfig
from .copilot_config_fab_value import CopilotConfigFabValue
from .copilot_config_mode import CopilotConfigMode
from .dependency import Dependency
from .document import Document
from .document_data_value import DocumentDataValue
from .edge_ui import EdgeUi
from .environment import Environment
from .environment_config import EnvironmentConfig
from .environment_deployment_config import EnvironmentDeploymentConfig
from .environment_deployment_config_revision_lookup import EnvironmentDeploymentConfigRevisionLookup
from .environment_deployment_document import EnvironmentDeploymentDocument
from .eval_service_handlers_create_collection_response import EvalServiceHandlersCreateCollectionResponse
from .eval_service_handlers_create_document_response import EvalServiceHandlersCreateDocumentResponse
from .eval_service_handlers_create_table_response import EvalServiceHandlersCreateTableResponse
from .eval_service_handlers_delete_collection_response import EvalServiceHandlersDeleteCollectionResponse
from .eval_service_handlers_delete_document_response import EvalServiceHandlersDeleteDocumentResponse
from .eval_service_handlers_delete_table_response import EvalServiceHandlersDeleteTableResponse
from .eval_service_handlers_get_collection_response import EvalServiceHandlersGetCollectionResponse
from .eval_service_handlers_get_collections_response import EvalServiceHandlersGetCollectionsResponse
from .eval_service_handlers_get_document_response import EvalServiceHandlersGetDocumentResponse
from .eval_service_handlers_get_documents_response import EvalServiceHandlersGetDocumentsResponse
from .eval_service_handlers_get_table_response import EvalServiceHandlersGetTableResponse
from .eval_service_handlers_get_tables_response import EvalServiceHandlersGetTablesResponse
from .eval_service_handlers_update_collection_response import EvalServiceHandlersUpdateCollectionResponse
from .eval_service_handlers_update_document_response import EvalServiceHandlersUpdateDocumentResponse
from .eval_service_handlers_update_table_response import EvalServiceHandlersUpdateTableResponse
from .event_version import EventVersion
from .http_validation_error import HttpValidationError
from .identity import Identity
from .identity_details import IdentityDetails
from .identity_types import IdentityTypes
from .json_column import JsonColumn
from .markdown_column import MarkdownColumn
from .message import Message
from .message_chunk import MessageChunk
from .node_ui import NodeUi
from .number_column import NumberColumn
from .number_column_default import NumberColumnDefault
from .number_column_max_value import NumberColumnMaxValue
from .number_column_min_value import NumberColumnMinValue
from .position import Position
from .prompt import Prompt
from .prompt_role import PromptRole
from .response_model_usage import ResponseModelUsage
from .select_column import SelectColumn
from .select_option_item import SelectOptionItem
from .table import Table
from .table_config_input import TableConfigInput
from .table_config_input_schema_item import TableConfigInputSchemaItem
from .table_config_output import TableConfigOutput
from .table_config_output_schema_item import TableConfigOutputSchemaItem
from .text_long_column import TextLongColumn
from .text_short_column import TextShortColumn
from .url_column import UrlColumn
from .usage import Usage
from .user_identity import UserIdentity
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .workflow import Workflow
from .workflow_config_input import WorkflowConfigInput
from .workflow_config_output import WorkflowConfigOutput
from .workflow_run import WorkflowRun
from .workflow_run_completed import WorkflowRunCompleted
from .workflow_run_completed_data import WorkflowRunCompletedData
from .workflow_run_completed_environment import WorkflowRunCompletedEnvironment
from .workflow_run_failed import WorkflowRunFailed
from .workflow_run_failed_data import WorkflowRunFailedData
from .workflow_run_failed_environment import WorkflowRunFailedEnvironment
from .workflow_run_response import WorkflowRunResponse
from .workflow_run_started import WorkflowRunStarted
from .workflow_run_started_data import WorkflowRunStartedData
from .workflow_run_started_environment import WorkflowRunStartedEnvironment
from .workflow_run_state_value import WorkflowRunStateValue
from .workflow_run_stop_reason import WorkflowRunStopReason
from .workflow_run_stream_response import WorkflowRunStreamResponse

__all__ = [
    "Actor",
    "ActorType",
    "ApiKeyIdentity",
    "AppsServiceHandlersCreateCopilotResponse",
    "AppsServiceHandlersCreateWorkflowResponse",
    "AppsServiceHandlersDeleteCopilotResponse",
    "AppsServiceHandlersDeleteWorkflowResponse",
    "AppsServiceHandlersDeleteWorkflowRevisionResponse",
    "AppsServiceHandlersGetCopilotResponse",
    "AppsServiceHandlersGetWorkflowEnvironmentsResponse",
    "AppsServiceHandlersGetWorkflowResponse",
    "AppsServiceHandlersListCopilotsResponse",
    "AppsServiceHandlersListWorkflowRevisionsResponse",
    "AppsServiceHandlersListWorkflowsResponse",
    "AppsServiceHandlersPromoteWorkflowRevisionResponse",
    "AppsServiceHandlersUpdateCopilotResponse",
    "AppsServiceHandlersUpdateWorkflowEnvironmentResponse",
    "AppsServiceHandlersUpdateWorkflowResponse",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CheckBoxColumn",
    "Collection",
    "CollectionConfig",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "Dependency",
    "Document",
    "DocumentDataValue",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EvalServiceHandlersCreateCollectionResponse",
    "EvalServiceHandlersCreateDocumentResponse",
    "EvalServiceHandlersCreateTableResponse",
    "EvalServiceHandlersDeleteCollectionResponse",
    "EvalServiceHandlersDeleteDocumentResponse",
    "EvalServiceHandlersDeleteTableResponse",
    "EvalServiceHandlersGetCollectionResponse",
    "EvalServiceHandlersGetCollectionsResponse",
    "EvalServiceHandlersGetDocumentResponse",
    "EvalServiceHandlersGetDocumentsResponse",
    "EvalServiceHandlersGetTableResponse",
    "EvalServiceHandlersGetTablesResponse",
    "EvalServiceHandlersUpdateCollectionResponse",
    "EvalServiceHandlersUpdateDocumentResponse",
    "EvalServiceHandlersUpdateTableResponse",
    "EventVersion",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "JsonColumn",
    "MarkdownColumn",
    "Message",
    "MessageChunk",
    "NodeUi",
    "NumberColumn",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "Position",
    "Prompt",
    "PromptRole",
    "ResponseModelUsage",
    "SelectColumn",
    "SelectOptionItem",
    "Table",
    "TableConfigInput",
    "TableConfigInputSchemaItem",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TextLongColumn",
    "TextShortColumn",
    "UrlColumn",
    "Usage",
    "UserIdentity",
    "ValidationError",
    "ValidationErrorLocItem",
    "Workflow",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    DocumentsCreateRequest,
    DocumentsCreateRequestItemValue,
    DocumentsCreateRequestZeroValue,
    DocumentsUpdateRequestValue,
)

__all__ = [
    "DocumentsCreateRequest",
    "DocumentsCreateRequestItemValue",
    "DocumentsCreateRequestZeroValue",
    "DocumentsUpdateRequestValue",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .block_config_item_boolean import BlockConfigItemBoolean
from .block_config_item_json import BlockConfigItemJson
from .block_config_item_number import BlockConfigItemNumber
from .block_config_item_llm import BlockConfigItemLlm
from .block_config_item_select import BlockConfigItemSelect
from .block_config_item_text_long import BlockConfigItemTextLong
from .block_config_item_text_short import BlockConfigItemTextShort

BlockOutputBlockConfigItem = typing.Union[
    BlockConfigItemBoolean,
    BlockConfigItemJson,
    BlockConfigItemNumber,
    BlockConfigItemLlm,
    BlockConfigItemSelect,
    BlockConfigItemTextLong,
    BlockConfigItemTextShort,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .table_config_output import TableConfigOutput
import typing
import datetime as dt
from .identity import Identity
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Table(UncheckedBaseModel):
    table_config: TableConfigOutput
    created_at: typing.Optional[dt.datetime] = None
    last_updated_at: typing.Optional[dt.datetime] = None
    created_by: Identity
    last_updated_by: Identity
    revision_id: str
    table_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .block_config_item_number_default_value import BlockConfigItemNumberDefaultValue
from .block_config_item_number_minimum_value import BlockConfigItemNumberMinimumValue
from .block_config_item_number_maximum_value import BlockConfigItemNumberMaximumValue
from .block_config_item_number_value import BlockConfigItemNumberValue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class BlockConfigItemNumber(UncheckedBaseModel):
    id: str
    display_name: str
    type: typing.Literal["number"] = "number"
    default_value: typing.Optional[BlockConfigItemNumberDefaultValue] = None
    minimum_value: typing.Optional[BlockConfigItemNumberMinimumValue] = None
    maximum_value: typing.Optional[BlockConfigItemNumberMaximumValue] = None
    value: typing.Optional[BlockConfigItemNumberValue] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .workflows_run_request_inputs_value import WorkflowsRunRequestInputsValue
from .workflows_run_stream_request_inputs_value import WorkflowsRunStreamRequestInputsValue

__all__ = ["WorkflowsRunRequestInputsValue", "WorkflowsRunStreamRequestInputsValue"]



# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import ScoutEnvironment
import os
import httpx
from .core.api_error import ApiError
from .core.client_wrapper import SyncClientWrapper
from .workflows.client import WorkflowsClient
from .environments.client import EnvironmentsClient
from .revisions.client import RevisionsClient
from .usage.client import UsageClient
from .workflow_logs.client import WorkflowLogsClient
from .copilots.client import CopilotsClient
from .collections.client import CollectionsClient
from .tables.client import TablesClient
from .documents.client import DocumentsClient
from .core.client_wrapper import AsyncClientWrapper
from .workflows.client import AsyncWorkflowsClient
from .environments.client import AsyncEnvironmentsClient
from .revisions.client import AsyncRevisionsClient
from .usage.client import AsyncUsageClient
from .workflow_logs.client import AsyncWorkflowLogsClient
from .copilots.client import AsyncCopilotsClient
from .collections.client import AsyncCollectionsClient
from .tables.client import AsyncTablesClient
from .documents.client import AsyncDocumentsClient


class Scout:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ScoutEnvironment
        The environment to use for requests from the client. from .environment import ScoutEnvironment



        Defaults to ScoutEnvironment.PROD



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from scoutos import Scout

    client = Scout(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ScoutEnvironment = ScoutEnvironment.PROD,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SCOUT_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        if api_key is None:
            raise ApiError(body="The client must be instantiated be either passing in api_key or setting SCOUT_API_KEY")
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.workflows = WorkflowsClient(client_wrapper=self._client_wrapper)
        self.environments = EnvironmentsClient(client_wrapper=self._client_wrapper)
        self.revisions = RevisionsClient(client_wrapper=self._client_wrapper)
        self.usage = UsageClient(client_wrapper=self._client_wrapper)
        self.workflow_logs = WorkflowLogsClient(client_wrapper=self._client_wrapper)
        self.copilots = CopilotsClient(client_wrapper=self._client_wrapper)
        self.collections = CollectionsClient(client_wrapper=self._client_wrapper)
        self.tables = TablesClient(client_wrapper=self._client_wrapper)
        self.documents = DocumentsClient(client_wrapper=self._client_wrapper)


class AsyncScout:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ScoutEnvironment
        The environment to use for requests from the client. from .environment import ScoutEnvironment



        Defaults to ScoutEnvironment.PROD



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from scoutos import AsyncScout

    client = AsyncScout(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ScoutEnvironment = ScoutEnvironment.PROD,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SCOUT_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        if api_key is None:
            raise ApiError(body="The client must be instantiated be either passing in api_key or setting SCOUT_API_KEY")
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.workflows = AsyncWorkflowsClient(client_wrapper=self._client_wrapper)
        self.environments = AsyncEnvironmentsClient(client_wrapper=self._client_wrapper)
        self.revisions = AsyncRevisionsClient(client_wrapper=self._client_wrapper)
        self.usage = AsyncUsageClient(client_wrapper=self._client_wrapper)
        self.workflow_logs = AsyncWorkflowLogsClient(client_wrapper=self._client_wrapper)
        self.copilots = AsyncCopilotsClient(client_wrapper=self._client_wrapper)
        self.collections = AsyncCollectionsClient(client_wrapper=self._client_wrapper)
        self.tables = AsyncTablesClient(client_wrapper=self._client_wrapper)
        self.documents = AsyncDocumentsClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ScoutEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")
